@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,12 +27,16 @@
 
 
 
+
 from .fetchers import NUTCAsFetcher
 
 
 from .fetchers import NURedirectionTargetsFetcher
 
 
+from .fetchers import NUDeploymentFailuresFetcher
+
+
 from .fetchers import NUPermissionsFetcher
 
 
@@ -57,9 +61,6 @@ from .fetchers import NUEgressAdvFwdTemplatesFetcher
 from .fetchers import NUDomainFIPAclTemplatesFetcher
 
 
-from .fetchers import NUFloatingIPACLTemplatesFetcher
-
-
 from .fetchers import NUDHCPOptionsFetcher
 
 
@@ -69,6 +70,15 @@ from .fetchers import NULinksFetcher
 from .fetchers import NUFirewallAclsFetcher
 
 
+from .fetchers import NUVirtualFirewallPoliciesFetcher
+
+
+from .fetchers import NUVirtualFirewallRulesFetcher
+
+
+from .fetchers import NUAlarmsFetcher
+
+
 from .fetchers import NUFloatingIpsFetcher
 
 
@@ -93,9 +103,6 @@ from .fetchers import NUIngressACLTemplatesFetcher
 from .fetchers import NUIngressAdvFwdTemplatesFetcher
 
 
-from .fetchers import NUIngressExternalServiceTemplatesFetcher
-
-
 from .fetchers import NUJobsFetcher
 
 
@@ -117,6 +124,9 @@ from .fetchers import NUContainersFetcher
 from .fetchers import NUContainerInterfacesFetcher
 
 
+from .fetchers import NUForwardingPathListsFetcher
+
+
 from .fetchers import NUQOSsFetcher
 
 
@@ -138,6 +148,9 @@ from .fetchers import NUVPNConnectionsFetcher
 from .fetchers import NUVPortsFetcher
 
 
+from .fetchers import NUApplicationsFetcher
+
+
 from .fetchers import NUApplicationperformancemanagementbindingsFetcher
 
 
@@ -147,6 +160,15 @@ from .fetchers import NUBridgeInterfacesFetcher
 from .fetchers import NUGroupsFetcher
 
 
+from .fetchers import NUNSGatewaySummariesFetcher
+
+
+from .fetchers import NUNSGRoutingPolicyBindingsFetcher
+
+
+from .fetchers import NUOSPFInstancesFetcher
+
+
 from .fetchers import NUStaticRoutesFetcher
 
 
@@ -193,25 +215,31 @@ class NUDomain(NURESTObject):
     
     CONST_POLICY_CHANGE_STATUS_DISCARDED = "DISCARDED"
     
+    CONST_FLOW_COLLECTION_ENABLED_DISABLED = "DISABLED"
+    
     CONST_DHCP_BEHAVIOR_UNDERLAY_RELAY = "UNDERLAY_RELAY"
     
     CONST_UNDERLAY_ENABLED_ENABLED = "ENABLED"
     
     CONST_MAINTENANCE_MODE_DISABLED = "DISABLED"
     
+    CONST_TUNNEL_TYPE_VLAN = "VLAN"
+    
     CONST_TUNNEL_TYPE_DC_DEFAULT = "DC_DEFAULT"
     
     CONST_MAINTENANCE_MODE_ENABLED = "ENABLED"
     
+    CONST_EVPNRT5_TYPE_IP = "IP"
+    
     CONST_PERMITTED_ACTION_EXTEND = "EXTEND"
     
     CONST_UPLINK_PREFERENCE_SYMMETRIC = "SYMMETRIC"
     
     CONST_PERMITTED_ACTION_INSTANTIATE = "INSTANTIATE"
     
-    CONST_DHCP_BEHAVIOR_OVERLAY_RELAY = "OVERLAY_RELAY"
+    CONST_EVPNRT5_TYPE_MAC = "MAC"
     
-    CONST_UNDERLAY_ENABLED_INHERITED = "INHERITED"
+    CONST_DHCP_BEHAVIOR_OVERLAY_RELAY = "OVERLAY_RELAY"
     
     CONST_POLICY_CHANGE_STATUS_STARTED = "STARTED"
     
@@ -221,6 +249,10 @@ class NUDomain(NURESTObject):
     
     CONST_PERMITTED_ACTION_USE = "USE"
     
+    CONST_FLOW_COLLECTION_ENABLED_ENABLED = "ENABLED"
+    
+    CONST_FLOW_COLLECTION_ENABLED_INHERITED = "INHERITED"
+    
     CONST_PAT_ENABLED_ENABLED = "ENABLED"
     
     CONST_MULTICAST_ENABLED = "ENABLED"
@@ -229,6 +261,8 @@ class NUDomain(NURESTObject):
     
     CONST_ADVERTISE_CRITERIA_HUB_ROUTES = "HUB_ROUTES"
     
+    CONST_FIP_IGNORE_DEFAULT_ROUTE_DISABLED = "DISABLED"
+    
     CONST_UPLINK_PREFERENCE_SECONDARY = "SECONDARY"
     
     CONST_DHCP_BEHAVIOR_FLOOD = "FLOOD"
@@ -247,15 +281,15 @@ class NUDomain(NURESTObject):
     
     CONST_DPI_DISABLED = "DISABLED"
     
-    CONST_MAINTENANCE_MODE_ENABLED_INHERITED = "ENABLED_INHERITED"
-    
     CONST_ENCRYPTION_ENABLED = "ENABLED"
     
+    CONST_UNDERLAY_ENABLED_DISABLED = "DISABLED"
+    
     CONST_TUNNEL_TYPE_GRE = "GRE"
     
     CONST_POLICY_CHANGE_STATUS_APPLIED = "APPLIED"
     
-    CONST_UNDERLAY_ENABLED_DISABLED = "DISABLED"
+    CONST_FIP_IGNORE_DEFAULT_ROUTE_ENABLED = "ENABLED"
     
     
 
@@ -281,13 +315,15 @@ class NUDomain(NURESTObject):
         self._bgp_enabled = None
         self._dhcp_behavior = None
         self._dhcp_server_address = None
+        self._fip_ignore_default_route = None
         self._fip_underlay = None
         self._dpi = None
+        self._evpnrt5_type = None
+        self._vxlanecmp_enabled = None
         self._label_id = None
         self._back_haul_route_distinguisher = None
         self._back_haul_route_target = None
-        self._back_haul_subnet_ip_address = None
-        self._back_haul_subnet_mask = None
+        self._back_haul_service_id = None
         self._back_haul_vnid = None
         self._maintenance_mode = None
         self._name = None
@@ -299,11 +335,14 @@ class NUDomain(NURESTObject):
         self._permitted_action = None
         self._service_id = None
         self._description = None
+        self._aggregate_flows_enabled = None
         self._dhcp_server_addresses = None
         self._global_routing_enabled = None
+        self._flow_collection_enabled = None
         self._import_route_target = None
         self._encryption = None
         self._underlay_enabled = None
+        self._enterprise_id = None
         self._entity_scope = None
         self._local_as = None
         self._policy_change_status = None
@@ -316,27 +355,31 @@ class NUDomain(NURESTObject):
         self._associated_multicast_channel_map_id = None
         self._associated_pat_mapper_id = None
         self._associated_shared_pat_mapper_id = None
+        self._associated_underlay_id = None
         self._stretched = None
         self._multicast = None
         self._tunnel_type = None
         self._customer_id = None
         self._export_route_target = None
         self._external_id = None
+        self._external_label = None
         
         self.expose_attribute(local_name="pat_enabled", remote_name="PATEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="ecmp_count", remote_name="ECMPCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="bgp_enabled", remote_name="BGPEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dhcp_behavior", remote_name="DHCPBehavior", attribute_type=str, is_required=False, is_unique=False, choices=[u'CONSUME', u'FLOOD', u'OVERLAY_RELAY', u'UNDERLAY_RELAY'])
         self.expose_attribute(local_name="dhcp_server_address", remote_name="DHCPServerAddress", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="fip_ignore_default_route", remote_name="FIPIgnoreDefaultRoute", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="fip_underlay", remote_name="FIPUnderlay", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
+        self.expose_attribute(local_name="evpnrt5_type", remote_name="EVPNRT5Type", attribute_type=str, is_required=False, is_unique=False, choices=[u'IP', u'MAC'])
+        self.expose_attribute(local_name="vxlanecmp_enabled", remote_name="VXLANECMPEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="label_id", remote_name="labelID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="back_haul_route_distinguisher", remote_name="backHaulRouteDistinguisher", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="back_haul_route_target", remote_name="backHaulRouteTarget", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="back_haul_subnet_ip_address", remote_name="backHaulSubnetIPAddress", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="back_haul_subnet_mask", remote_name="backHaulSubnetMask", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="back_haul_service_id", remote_name="backHaulServiceID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="back_haul_vnid", remote_name="backHaulVNID", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="maintenance_mode", remote_name="maintenanceMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'ENABLED_INHERITED'])
+        self.expose_attribute(local_name="maintenance_mode", remote_name="maintenanceMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="advertise_criteria", remote_name="advertiseCriteria", attribute_type=str, is_required=False, is_unique=False, choices=[u'HUB_ROUTES'])
@@ -346,11 +389,14 @@ class NUDomain(NURESTObject):
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
         self.expose_attribute(local_name="service_id", remote_name="serviceID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="aggregate_flows_enabled", remote_name="aggregateFlowsEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dhcp_server_addresses", remote_name="dhcpServerAddresses", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="global_routing_enabled", remote_name="globalRoutingEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="flow_collection_enabled", remote_name="flowCollectionEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="import_route_target", remote_name="importRouteTarget", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="encryption", remote_name="encryption", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
-        self.expose_attribute(local_name="underlay_enabled", remote_name="underlayEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
+        self.expose_attribute(local_name="underlay_enabled", remote_name="underlayEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
+        self.expose_attribute(local_name="enterprise_id", remote_name="enterpriseID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="local_as", remote_name="localAS", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="policy_change_status", remote_name="policyChangeStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'APPLIED', u'DISCARDED', u'STARTED'])
@@ -363,12 +409,14 @@ class NUDomain(NURESTObject):
         self.expose_attribute(local_name="associated_multicast_channel_map_id", remote_name="associatedMulticastChannelMapID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_pat_mapper_id", remote_name="associatedPATMapperID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_shared_pat_mapper_id", remote_name="associatedSharedPATMapperID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_underlay_id", remote_name="associatedUnderlayID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stretched", remote_name="stretched", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
-        self.expose_attribute(local_name="tunnel_type", remote_name="tunnelType", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC_DEFAULT', u'GRE', u'VXLAN'])
+        self.expose_attribute(local_name="tunnel_type", remote_name="tunnelType", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC_DEFAULT', u'GRE', u'VLAN', u'VXLAN'])
         self.expose_attribute(local_name="customer_id", remote_name="customerID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="export_route_target", remote_name="exportRouteTarget", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        self.expose_attribute(local_name="external_label", remote_name="externalLabel", attribute_type=str, is_required=False, is_unique=False)
         
 
         # Fetchers
@@ -380,6 +428,9 @@ class NUDomain(NURESTObject):
         self.redirection_targets = NURedirectionTargetsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.deployment_failures = NUDeploymentFailuresFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -404,9 +455,6 @@ class NUDomain(NURESTObject):
         self.domain_fip_acl_templates = NUDomainFIPAclTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.floating_ipacl_templates = NUFloatingIPACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.dhcp_options = NUDHCPOptionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -416,6 +464,15 @@ class NUDomain(NURESTObject):
         self.firewall_acls = NUFirewallAclsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.virtual_firewall_policies = NUVirtualFirewallPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.virtual_firewall_rules = NUVirtualFirewallRulesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.alarms = NUAlarmsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.floating_ips = NUFloatingIpsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -440,9 +497,6 @@ class NUDomain(NURESTObject):
         self.ingress_adv_fwd_templates = NUIngressAdvFwdTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.ingress_external_service_templates = NUIngressExternalServiceTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -464,6 +518,9 @@ class NUDomain(NURESTObject):
         self.container_interfaces = NUContainerInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.forwarding_path_lists = NUForwardingPathListsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.qoss = NUQOSsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -485,6 +542,9 @@ class NUDomain(NURESTObject):
         self.vports = NUVPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.applications = NUApplicationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.applicationperformancemanagementbindings = NUApplicationperformancemanagementbindingsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -494,6 +554,15 @@ class NUDomain(NURESTObject):
         self.groups = NUGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.ns_gateway_summaries = NUNSGatewaySummariesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.nsg_routing_policy_bindings = NUNSGRoutingPolicyBindingsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.ospf_instances = NUOSPFInstancesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.static_routes = NUStaticRoutesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -518,7 +587,7 @@ class NUDomain(NURESTObject):
         """ Get pat_enabled value.
 
             Notes:
-                Indicates whether PAT is enabled for the subnets in this domain - ENABLED/DISABLED Possible values are INHERITED, ENABLED, DISABLED, .
+                Indicates whether PAT is enabled for the subnets in this domain - ENABLED/DISABLED Possible values are ENABLED, DISABLED.
 
                 
                 This attribute is named `PATEnabled` in VSD API.
@@ -531,7 +600,7 @@ class NUDomain(NURESTObject):
         """ Set pat_enabled value.
 
             Notes:
-                Indicates whether PAT is enabled for the subnets in this domain - ENABLED/DISABLED Possible values are INHERITED, ENABLED, DISABLED, .
+                Indicates whether PAT is enabled for the subnets in this domain - ENABLED/DISABLED Possible values are ENABLED, DISABLED.
 
                 
                 This attribute is named `PATEnabled` in VSD API.
@@ -648,6 +717,33 @@ class NUDomain(NURESTObject):
         self._dhcp_server_address = value
 
     
+    @property
+    def fip_ignore_default_route(self):
+        """ Get fip_ignore_default_route value.
+
+            Notes:
+                Determines whether the default Overlay route will be ignored or not when a VM has FIP so that it takes Underlay route.
+
+                
+                This attribute is named `FIPIgnoreDefaultRoute` in VSD API.
+                
+        """
+        return self._fip_ignore_default_route
+
+    @fip_ignore_default_route.setter
+    def fip_ignore_default_route(self, value):
+        """ Set fip_ignore_default_route value.
+
+            Notes:
+                Determines whether the default Overlay route will be ignored or not when a VM has FIP so that it takes Underlay route.
+
+                
+                This attribute is named `FIPIgnoreDefaultRoute` in VSD API.
+                
+        """
+        self._fip_ignore_default_route = value
+
+    
     @property
     def fip_underlay(self):
         """ Get fip_underlay value.
@@ -702,6 +798,60 @@ class NUDomain(NURESTObject):
         self._dpi = value
 
     
+    @property
+    def evpnrt5_type(self):
+        """ Get evpnrt5_type value.
+
+            Notes:
+                Determines whether EVPN-RT5 are enabled on this domain.
+
+                
+                This attribute is named `EVPNRT5Type` in VSD API.
+                
+        """
+        return self._evpnrt5_type
+
+    @evpnrt5_type.setter
+    def evpnrt5_type(self, value):
+        """ Set evpnrt5_type value.
+
+            Notes:
+                Determines whether EVPN-RT5 are enabled on this domain.
+
+                
+                This attribute is named `EVPNRT5Type` in VSD API.
+                
+        """
+        self._evpnrt5_type = value
+
+    
+    @property
+    def vxlanecmp_enabled(self):
+        """ Get vxlanecmp_enabled value.
+
+            Notes:
+                Determines whether VXLAN-ECMP are enabled on this domain.
+
+                
+                This attribute is named `VXLANECMPEnabled` in VSD API.
+                
+        """
+        return self._vxlanecmp_enabled
+
+    @vxlanecmp_enabled.setter
+    def vxlanecmp_enabled(self, value):
+        """ Set vxlanecmp_enabled value.
+
+            Notes:
+                Determines whether VXLAN-ECMP are enabled on this domain.
+
+                
+                This attribute is named `VXLANECMPEnabled` in VSD API.
+                
+        """
+        self._vxlanecmp_enabled = value
+
+    
     @property
     def label_id(self):
         """ Get label_id value.
@@ -734,7 +884,7 @@ class NUDomain(NURESTObject):
         """ Get back_haul_route_distinguisher value.
 
             Notes:
-                Route distinguisher associated with the BackHaul Service in dVRS. If not provided during creation, System generates this identifier automatically
+                Route distinguisher associated with the backhaul service in dVRS. If not provided, system generates this identifier automatically. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `backHaulRouteDistinguisher` in VSD API.
@@ -747,7 +897,7 @@ class NUDomain(NURESTObject):
         """ Set back_haul_route_distinguisher value.
 
             Notes:
-                Route distinguisher associated with the BackHaul Service in dVRS. If not provided during creation, System generates this identifier automatically
+                Route distinguisher associated with the backhaul service in dVRS. If not provided, system generates this identifier automatically. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `backHaulRouteDistinguisher` in VSD API.
@@ -761,7 +911,7 @@ class NUDomain(NURESTObject):
         """ Get back_haul_route_target value.
 
             Notes:
-                Route target associated with the BackHaul Service in dVRS. If not provided during creation, System generates this identifier automatically
+                Route target associated with the backhaul service in dVRS. If not provided, system generates this identifier automatically. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `backHaulRouteTarget` in VSD API.
@@ -774,7 +924,7 @@ class NUDomain(NURESTObject):
         """ Set back_haul_route_target value.
 
             Notes:
-                Route target associated with the BackHaul Service in dVRS. If not provided during creation, System generates this identifier automatically
+                Route target associated with the backhaul service in dVRS. If not provided, system generates this identifier automatically. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `backHaulRouteTarget` in VSD API.
@@ -784,57 +934,30 @@ class NUDomain(NURESTObject):
 
     
     @property
-    def back_haul_subnet_ip_address(self):
-        """ Get back_haul_subnet_ip_address value.
+    def back_haul_service_id(self):
+        """ Get back_haul_service_id value.
 
             Notes:
-                IP Address of the backhaul subnet 
+                The backhaul serviceID of the Virtual Router created in VSC and is associated with this object. This is auto-generated by VSD
 
                 
-                This attribute is named `backHaulSubnetIPAddress` in VSD API.
+                This attribute is named `backHaulServiceID` in VSD API.
                 
         """
-        return self._back_haul_subnet_ip_address
+        return self._back_haul_service_id
 
-    @back_haul_subnet_ip_address.setter
-    def back_haul_subnet_ip_address(self, value):
-        """ Set back_haul_subnet_ip_address value.
+    @back_haul_service_id.setter
+    def back_haul_service_id(self, value):
+        """ Set back_haul_service_id value.
 
             Notes:
-                IP Address of the backhaul subnet 
+                The backhaul serviceID of the Virtual Router created in VSC and is associated with this object. This is auto-generated by VSD
 
                 
-                This attribute is named `backHaulSubnetIPAddress` in VSD API.
+                This attribute is named `backHaulServiceID` in VSD API.
                 
         """
-        self._back_haul_subnet_ip_address = value
-
-    
-    @property
-    def back_haul_subnet_mask(self):
-        """ Get back_haul_subnet_mask value.
-
-            Notes:
-                Network mask of the backhaul subnet
-
-                
-                This attribute is named `backHaulSubnetMask` in VSD API.
-                
-        """
-        return self._back_haul_subnet_mask
-
-    @back_haul_subnet_mask.setter
-    def back_haul_subnet_mask(self, value):
-        """ Set back_haul_subnet_mask value.
-
-            Notes:
-                Network mask of the backhaul subnet
-
-                
-                This attribute is named `backHaulSubnetMask` in VSD API.
-                
-        """
-        self._back_haul_subnet_mask = value
+        self._back_haul_service_id = value
 
     
     @property
@@ -842,7 +965,7 @@ class NUDomain(NURESTObject):
         """ Get back_haul_vnid value.
 
             Notes:
-                Current BackHaul Network's globally unique  VXLAN network identifier generated by VSD
+                Current backhaul network's globally unique VXLAN network identifier
 
                 
                 This attribute is named `backHaulVNID` in VSD API.
@@ -855,7 +978,7 @@ class NUDomain(NURESTObject):
         """ Set back_haul_vnid value.
 
             Notes:
-                Current BackHaul Network's globally unique  VXLAN network identifier generated by VSD
+                Current backhaul network's globally unique VXLAN network identifier
 
                 
                 This attribute is named `backHaulVNID` in VSD API.
@@ -869,7 +992,7 @@ class NUDomain(NURESTObject):
         """ Get maintenance_mode value.
 
             Notes:
-                maintenanceMode is an enum that indicates if the Domain is accepting VM activation requests. Possible values are DISABLED, ENABLED and ENABLED_INHERITED Possible values are .
+                Enum that indicates if the Domain is accepting VM activation requests. Possible values are DISABLED, ENABLED.
 
                 
                 This attribute is named `maintenanceMode` in VSD API.
@@ -882,7 +1005,7 @@ class NUDomain(NURESTObject):
         """ Set maintenance_mode value.
 
             Notes:
-                maintenanceMode is an enum that indicates if the Domain is accepting VM activation requests. Possible values are DISABLED, ENABLED and ENABLED_INHERITED Possible values are .
+                Enum that indicates if the Domain is accepting VM activation requests. Possible values are DISABLED, ENABLED.
 
                 
                 This attribute is named `maintenanceMode` in VSD API.
@@ -1126,6 +1249,33 @@ class NUDomain(NURESTObject):
         self._description = value
 
     
+    @property
+    def aggregate_flows_enabled(self):
+        """ Get aggregate_flows_enabled value.
+
+            Notes:
+                Flag to enable aggregate flows on this domain.
+
+                
+                This attribute is named `aggregateFlowsEnabled` in VSD API.
+                
+        """
+        return self._aggregate_flows_enabled
+
+    @aggregate_flows_enabled.setter
+    def aggregate_flows_enabled(self, value):
+        """ Set aggregate_flows_enabled value.
+
+            Notes:
+                Flag to enable aggregate flows on this domain.
+
+                
+                This attribute is named `aggregateFlowsEnabled` in VSD API.
+                
+        """
+        self._aggregate_flows_enabled = value
+
+    
     @property
     def dhcp_server_addresses(self):
         """ Get dhcp_server_addresses value.
@@ -1180,6 +1330,33 @@ class NUDomain(NURESTObject):
         self._global_routing_enabled = value
 
     
+    @property
+    def flow_collection_enabled(self):
+        """ Get flow_collection_enabled value.
+
+            Notes:
+                Determines whether or not flow collection is enabled.
+
+                
+                This attribute is named `flowCollectionEnabled` in VSD API.
+                
+        """
+        return self._flow_collection_enabled
+
+    @flow_collection_enabled.setter
+    def flow_collection_enabled(self, value):
+        """ Set flow_collection_enabled value.
+
+            Notes:
+                Determines whether or not flow collection is enabled.
+
+                
+                This attribute is named `flowCollectionEnabled` in VSD API.
+                
+        """
+        self._flow_collection_enabled = value
+
+    
     @property
     def import_route_target(self):
         """ Get import_route_target value.
@@ -1212,7 +1389,7 @@ class NUDomain(NURESTObject):
         """ Get encryption value.
 
             Notes:
-                Determines whether IPSEC is enabled Possible values are ENABLED, DISABLED, .
+                Determines whether IPSEC is enabled Possible values are ENABLED, DISABLED.
 
                 
         """
@@ -1223,7 +1400,7 @@ class NUDomain(NURESTObject):
         """ Set encryption value.
 
             Notes:
-                Determines whether IPSEC is enabled Possible values are ENABLED, DISABLED, .
+                Determines whether IPSEC is enabled Possible values are ENABLED, DISABLED.
 
                 
         """
@@ -1257,6 +1434,33 @@ class NUDomain(NURESTObject):
         self._underlay_enabled = value
 
     
+    @property
+    def enterprise_id(self):
+        """ Get enterprise_id value.
+
+            Notes:
+                Enterprise ID
+
+                
+                This attribute is named `enterpriseID` in VSD API.
+                
+        """
+        return self._enterprise_id
+
+    @enterprise_id.setter
+    def enterprise_id(self, value):
+        """ Set enterprise_id value.
+
+            Notes:
+                Enterprise ID
+
+                
+                This attribute is named `enterpriseID` in VSD API.
+                
+        """
+        self._enterprise_id = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -1397,7 +1601,7 @@ class NUDomain(NURESTObject):
         """ Get route_distinguisher value.
 
             Notes:
-                Route distinguisher associated with the dVRS. It is an optional parameter that can be provided by the user or auto-managed by VSD. System generates this identifier automatically, if not provided
+                Route distinguisher associated with the dVRS. If not provided, system generates this identifier automatically. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `routeDistinguisher` in VSD API.
@@ -1410,7 +1614,7 @@ class NUDomain(NURESTObject):
         """ Set route_distinguisher value.
 
             Notes:
-                Route distinguisher associated with the dVRS. It is an optional parameter that can be provided by the user or auto-managed by VSD. System generates this identifier automatically, if not provided
+                Route distinguisher associated with the dVRS. If not provided, system generates this identifier automatically. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `routeDistinguisher` in VSD API.
@@ -1424,7 +1628,7 @@ class NUDomain(NURESTObject):
         """ Get route_target value.
 
             Notes:
-                Route target associated with the dVRS. It is an optional parameterthat can be provided by the user or auto-managed by VSDSystem generates this identifier automatically, if not provided
+                Route target associated with the dVRS. If not provided, system generates this identifier automatically. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `routeTarget` in VSD API.
@@ -1437,7 +1641,7 @@ class NUDomain(NURESTObject):
         """ Set route_target value.
 
             Notes:
-                Route target associated with the dVRS. It is an optional parameterthat can be provided by the user or auto-managed by VSDSystem generates this identifier automatically, if not provided
+                Route target associated with the dVRS. If not provided, system generates this identifier automatically. Supported formats are: [2-byte ASN]:[4-byte value] or [4-byte ASN]:[2-byte value]
 
                 
                 This attribute is named `routeTarget` in VSD API.
@@ -1581,6 +1785,33 @@ class NUDomain(NURESTObject):
         self._associated_shared_pat_mapper_id = value
 
     
+    @property
+    def associated_underlay_id(self):
+        """ Get associated_underlay_id value.
+
+            Notes:
+                The ID of the Underlay entity to which this L3 Domain is associated.
+
+                
+                This attribute is named `associatedUnderlayID` in VSD API.
+                
+        """
+        return self._associated_underlay_id
+
+    @associated_underlay_id.setter
+    def associated_underlay_id(self, value):
+        """ Set associated_underlay_id value.
+
+            Notes:
+                The ID of the Underlay entity to which this L3 Domain is associated.
+
+                
+                This attribute is named `associatedUnderlayID` in VSD API.
+                
+        """
+        self._associated_underlay_id = value
+
+    
     @property
     def stretched(self):
         """ Get stretched value.
@@ -1735,6 +1966,33 @@ class NUDomain(NURESTObject):
         self._external_id = value
 
     
+    @property
+    def external_label(self):
+        """ Get external_label value.
+
+            Notes:
+                External label given to Domain
+
+                
+                This attribute is named `externalLabel` in VSD API.
+                
+        """
+        return self._external_label
+
+    @external_label.setter
+    def external_label(self, value):
+        """ Set external_label value.
+
+            Notes:
+                External label given to Domain
+
+                
+                This attribute is named `externalLabel` in VSD API.
+                
+        """
+        self._external_label = value
+
+    
 
     
     ## Custom methods
