@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NURedirectionTargetTemplatesFetcher
 
 
@@ -36,13 +37,19 @@ from .fetchers import NUPermissionsFetcher
 from .fetchers import NUMetadatasFetcher
 
 
+from .fetchers import NUPGExpressionTemplatesFetcher
+
+
 from .fetchers import NUEgressACLTemplatesFetcher
 
 
+from .fetchers import NUEgressAdvFwdTemplatesFetcher
+
+
 from .fetchers import NUDomainFIPAclTemplatesFetcher
 
 
-from .fetchers import NUFloatingIPACLTemplatesFetcher
+from .fetchers import NUVirtualFirewallPoliciesFetcher
 
 
 from .fetchers import NUGlobalMetadatasFetcher
@@ -54,9 +61,6 @@ from .fetchers import NUIngressACLTemplatesFetcher
 from .fetchers import NUIngressAdvFwdTemplatesFetcher
 
 
-from .fetchers import NUIngressExternalServiceTemplatesFetcher
-
-
 from .fetchers import NUJobsFetcher
 
 
@@ -87,7 +91,7 @@ class NUDomainTemplate(NURESTObject):
     """ Represents a DomainTemplate in the VSD
 
         Notes:
-            Domains in VSD are created from domain templates. This object provides the definition of the Domain Template.
+            A domain is a distributed logical router that enables L2 and L3 communication. A domain template is a model that can be instantiated as often as required, thereby creating real, functioning domains.
     """
 
     __rest_name__ = "domaintemplate"
@@ -178,13 +182,19 @@ class NUDomainTemplate(NURESTObject):
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.pg_expression_templates = NUPGExpressionTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.egress_acl_templates = NUEgressACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.egress_adv_fwd_templates = NUEgressAdvFwdTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.domain_fip_acl_templates = NUDomainFIPAclTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.floating_ipacl_templates = NUFloatingIPACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        self.virtual_firewall_policies = NUVirtualFirewallPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
@@ -196,9 +206,6 @@ class NUDomainTemplate(NURESTObject):
         self.ingress_adv_fwd_templates = NUIngressAdvFwdTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.ingress_external_service_templates = NUIngressExternalServiceTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
