@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUTCAsFetcher
 
 
@@ -109,6 +110,8 @@ class NUHostInterface(NURESTObject):
         self._ip_address = None
         self._vport_id = None
         self._vport_name = None
+        self._ipv6_address = None
+        self._ipv6_gateway = None
         self._name = None
         self._last_updated_by = None
         self._gateway = None
@@ -121,15 +124,16 @@ class NUHostInterface(NURESTObject):
         self._domain_name = None
         self._zone_id = None
         self._zone_name = None
-        self._associated_floating_ip_address = None
         self._attached_network_id = None
         self._attached_network_type = None
         self._external_id = None
         
-        self.expose_attribute(local_name="mac", remote_name="MAC", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="mac", remote_name="MAC", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="ip_address", remote_name="IPAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vport_id", remote_name="VPortID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vport_name", remote_name="VPortName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ipv6_address", remote_name="IPv6Address", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ipv6_gateway", remote_name="IPv6Gateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway", remote_name="gateway", attribute_type=str, is_required=False, is_unique=False)
@@ -142,7 +146,6 @@ class NUHostInterface(NURESTObject):
         self.expose_attribute(local_name="domain_name", remote_name="domainName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="zone_id", remote_name="zoneID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="zone_name", remote_name="zoneName", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="associated_floating_ip_address", remote_name="associatedFloatingIPAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="attached_network_id", remote_name="attachedNetworkID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="attached_network_type", remote_name="attachedNetworkType", attribute_type=str, is_required=False, is_unique=False, choices=[u'L2DOMAIN', u'SUBNET'])
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
@@ -299,6 +302,60 @@ class NUHostInterface(NURESTObject):
         self._vport_name = value
 
     
+    @property
+    def ipv6_address(self):
+        """ Get ipv6_address value.
+
+            Notes:
+                IPv6 address of the  interface
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        return self._ipv6_address
+
+    @ipv6_address.setter
+    def ipv6_address(self, value):
+        """ Set ipv6_address value.
+
+            Notes:
+                IPv6 address of the  interface
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        self._ipv6_address = value
+
+    
+    @property
+    def ipv6_gateway(self):
+        """ Get ipv6_gateway value.
+
+            Notes:
+                IPV6 Gateway of the subnet that the host is connected to
+
+                
+                This attribute is named `IPv6Gateway` in VSD API.
+                
+        """
+        return self._ipv6_gateway
+
+    @ipv6_gateway.setter
+    def ipv6_gateway(self, value):
+        """ Set ipv6_gateway value.
+
+            Notes:
+                IPV6 Gateway of the subnet that the host is connected to
+
+                
+                This attribute is named `IPv6Gateway` in VSD API.
+                
+        """
+        self._ipv6_gateway = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -611,33 +668,6 @@ class NUHostInterface(NURESTObject):
         self._zone_name = value
 
     
-    @property
-    def associated_floating_ip_address(self):
-        """ Get associated_floating_ip_address value.
-
-            Notes:
-                Floating Ip Address of this network interface eg: 10.1.2.1
-
-                
-                This attribute is named `associatedFloatingIPAddress` in VSD API.
-                
-        """
-        return self._associated_floating_ip_address
-
-    @associated_floating_ip_address.setter
-    def associated_floating_ip_address(self, value):
-        """ Set associated_floating_ip_address value.
-
-            Notes:
-                Floating Ip Address of this network interface eg: 10.1.2.1
-
-                
-                This attribute is named `associatedFloatingIPAddress` in VSD API.
-                
-        """
-        self._associated_floating_ip_address = value
-
-    
     @property
     def attached_network_id(self):
         """ Get attached_network_id value.
