@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -161,7 +162,7 @@ class NUNSGatewayTemplate(NURESTObject):
         """ Get name value.
 
             Notes:
-                Name of the Gateway
+                Name of the Gateway template.
 
                 
         """
@@ -172,7 +173,7 @@ class NUNSGatewayTemplate(NURESTObject):
         """ Set name value.
 
             Notes:
-                Name of the Gateway
+                Name of the Gateway template.
 
                 
         """
@@ -211,7 +212,7 @@ class NUNSGatewayTemplate(NURESTObject):
         """ Get personality value.
 
             Notes:
-                Personality of the Gateway - NSG, NSGBR, cannot be changed after creation.
+                Personality of the Gateway template - NSG, NSGBR, cannot be changed after creation.
 
                 
         """
@@ -222,7 +223,7 @@ class NUNSGatewayTemplate(NURESTObject):
         """ Set personality value.
 
             Notes:
-                Personality of the Gateway - NSG, NSGBR, cannot be changed after creation.
+                Personality of the Gateway template - NSG, NSGBR, cannot be changed after creation.
 
                 
         """
@@ -234,7 +235,7 @@ class NUNSGatewayTemplate(NURESTObject):
         """ Get description value.
 
             Notes:
-                A description of the Gateway
+                A description of the Gateway template.
 
                 
         """
@@ -245,7 +246,7 @@ class NUNSGatewayTemplate(NURESTObject):
         """ Set description value.
 
             Notes:
-                A description of the Gateway
+                A description of the Gateway template.
 
                 
         """
@@ -284,7 +285,7 @@ class NUNSGatewayTemplate(NURESTObject):
         """ Get infrastructure_profile_id value.
 
             Notes:
-                The ID of the infrastructure gateway profile this instance of a Gateway is associated with.
+                The ID of the infrastructure gateway profile this instance of a Gateway template is associated with.
 
                 
                 This attribute is named `infrastructureProfileID` in VSD API.
@@ -297,7 +298,7 @@ class NUNSGatewayTemplate(NURESTObject):
         """ Set infrastructure_profile_id value.
 
             Notes:
-                The ID of the infrastructure gateway profile this instance of a Gateway is associated with.
+                The ID of the infrastructure gateway profile this instance of a Gateway template is associated with.
 
                 
                 This attribute is named `infrastructureProfileID` in VSD API.
@@ -338,7 +339,7 @@ class NUNSGatewayTemplate(NURESTObject):
         """ Get enterprise_id value.
 
             Notes:
-                The enterprise associated with this Gateway. This is a read only attribute
+                The enterprise associated with this Gateway template. This is a read only attribute
 
                 
                 This attribute is named `enterpriseID` in VSD API.
@@ -351,7 +352,7 @@ class NUNSGatewayTemplate(NURESTObject):
         """ Set enterprise_id value.
 
             Notes:
-                The enterprise associated with this Gateway. This is a read only attribute
+                The enterprise associated with this Gateway template. This is a read only attribute
 
                 
                 This attribute is named `enterpriseID` in VSD API.
